@@ -5,6 +5,7 @@ import uuid
 import six
 
 from dagster import (
+    AssetMaterialization,
     ExpectationResult,
     Failure,
     Materialization,
@@ -45,8 +46,12 @@ class DagstermillResourceEventGenerationManager(EventGenerationManager):
         return iter(())
 
     def teardown(self):
-        for _ in super(DagstermillResourceEventGenerationManager, self).generate_teardown_events():
-            pass
+        return [
+            teardown_event
+            for teardown_event in super(
+                DagstermillResourceEventGenerationManager, self
+            ).generate_teardown_events()
+        ]
 
 
 class Manager(object):
@@ -147,7 +152,9 @@ class Manager(object):
                 pipeline_context=pipeline_context,
                 solid_config=None,
                 resource_keys_to_init=get_required_resource_keys_to_init(
-                    execution_plan, pipeline_context.system_storage_def
+                    execution_plan,
+                    pipeline_context.system_storage_def,
+                    pipeline_context.intermediate_storage_def,
                 ),
             )
 
@@ -228,7 +235,9 @@ class Manager(object):
                 pipeline_context=pipeline_context,
                 solid_config=solid_config,
                 resource_keys_to_init=get_required_resource_keys_to_init(
-                    execution_plan, pipeline_context.system_storage_def
+                    execution_plan,
+                    pipeline_context.system_storage_def,
+                    pipeline_context.intermediate_storage_def,
                 ),
             )
 
@@ -271,7 +280,9 @@ class Manager(object):
                 An event to yield back to Dagster.
         '''
         check.inst_param(
-            dagster_event, 'dagster_event', (Materialization, ExpectationResult, TypeCheck, Failure)
+            dagster_event,
+            'dagster_event',
+            (AssetMaterialization, Materialization, ExpectationResult, TypeCheck, Failure),
         )
 
         if not self.in_pipeline:
